mod font;
mod writer;

use std::{error::Error, fs::File};

use clap::Parser;
use font::Font;
use log::{error, LevelFilter};
use simplelog::{ColorChoice, Config, TermLogger, TerminalMode};
use writer::{SvgWriter, Visitor};

#[derive(Parser, Debug)]
#[command(version, about, long_about = None)]
struct Args {
    file: String,
    glyph: char
}

fn main() -> Result<(), Box<dyn Error>> {
    TermLogger::init(
        LevelFilter::Debug,
        Config::default(),
        TerminalMode::Mixed,
        ColorChoice::Auto
    )?;

    let args = Args::parse();

    let font = Font::new(File::open(args.file)?);
    let Ok(mut font) = font else {
        let err = font.unwrap_err().to_string();
        error!("{err}");
        return Err(String::from(err).into());
    };

    // dbg!(font);

    let glyph = match font.get_data_for(args.glyph) {
        Ok(glyph) => glyph,
        Err(err) => {
            error!("{err}");
            return Err(err);
        }
    };

    let svg_file = File::create("out.svg")?;
    let mut writer = SvgWriter::new(svg_file);

    writer.write(&glyph);

    Ok(())
}
